about summary refs log tree commit diff
path: root/third_party/nixpkgs/default.nix
diff options
context:
space:
mode:
Diffstat (limited to 'third_party/nixpkgs/default.nix')
-rw-r--r--third_party/nixpkgs/default.nix10
1 files changed, 7 insertions, 3 deletions
diff --git a/third_party/nixpkgs/default.nix b/third_party/nixpkgs/default.nix
index 73b3b8b953..dbdd068a86 100644
--- a/third_party/nixpkgs/default.nix
+++ b/third_party/nixpkgs/default.nix
@@ -45,9 +45,13 @@ let
   # instead (e.g. because something is broken in unstable).
   # Use `stableNixpkgs` from above.
   stableOverlay = _unstableSelf: _unstableSuper: {
-    # bat syntaxes changed with syntect 5.0, but cheddar is still on 4.x
-    # TODO(tazjin): upgrade cheddar to syntect 5.0
-    bat = stableNixpkgs.bat;
+    inherit (stableNixpkgs)
+      # bat syntaxes changed with syntect 5.0, but cheddar is still on 4.x
+      # TODO(tazjin): upgrade cheddar to syntect 5.0
+      bat
+      # TODO(sterni): Temporarily use awscli2 from stable, since it broke in unstable
+      awscli2
+      ;
   };
 
   # Overlay to expose the nixpkgs commits we are using to other Nix code.